==> nmrium-0.50.0.tgz: package/lib/component/panels/spectrumSimulation/SpectrumSimulation.js <==
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { Formik } from 'formik';
import { useCallback, useState, useRef, useMemo } from 'react';
import * as Yup from 'yup';
import { defaultSimulationOptions, } from '../../../data/data1d/spectrumSimulation';
import { useDispatch } from '../../context/DispatchContext';
import Button from '../../elements/Button';
import FormikOnChange from '../../elements/formik/FormikOnChange';
import AboutSpectrumSimulationModal from '../../modal/AboutSpectrumSimulationModal';
import { tablePanelStyle } from '../extra/BasicPanelStyle';
import DefaultPanelHeader from '../header/DefaultPanelHeader';
import PreferencesHeader from '../header/PreferencesHeader';
import SpectrumSimulationPreferences from './SpectrumSimulationPreferences';
import SpectrumSimulationSimpleOptions from './SpectrumSimulationSimpleOptions';
import { SpinSystemTable } from './SpinSystemTable';
const validationSchema = Yup.object({
    data: Yup.array().of(Yup.array().of(Yup.lazy((value) => {
        if (value === null) {
            return Yup.mixed().nullable();
        }
        return Yup.number().required();
    }))),
});
export default function SpectrumSimulation() {
    const dispatch = useDispatch();
    const [isFlipped, setFlipStatus] = useState(false);
    const [spinSystem, setSpinSystem] = useState('AB');
    const spinSystemRef = useRef('AB');
    const formRef = useRef(null);
    const settingRef = useRef(null);
    const settingsPanelHandler = useCallback(() => {
        setFlipStatus(!isFlipped);
    }, [isFlipped]);
    const saveSettingHandler = useCallback(() => {
        settingRef.current?.saveSetting();
        setFlipStatus(false);
    }, []);
    function spinSystemChangeHandler(system) {
        spinSystemRef.current = system;
        setSpinSystem(system);
    }
    const data = useMemo(() => {
        const rows = [];
        const spinLength = spinSystem.length;
        for (let i = 1; i <= spinLength; i++) {
            const columns = [];
            for (let j = 0; j < spinLength; j++) {
                if (j < i && i !== 1) {
                    columns.push(0);
                }
                else {
                    columns.push(null);
                }
            }
            columns[0] = i;
            rows.push(columns);
        }
        return rows;
    }, [spinSystem]);
    function simulateHandler(values, keepSpectrum = false) {
        if (validationSchema.isValidSync(values)) {
            dispatch({
                type: 'SIMULATE_SPECTRUM',
                payload: { ...values, spinSystem: spinSystemRef.current, keepSpectrum },
            });
        }
    }
    function addSpectrumHandler() {
        const values = formRef.current?.values;
        if (values) {
            simulateHandler(values, true);
        }
    }
    function saveSettingsHandler(values) {
        simulateHandler(values);
        void formRef.current?.setValues(values);
    }
    return (_jsx(Formik, { initialValues: { ...defaultSimulationOptions, data }, enableReinitialize: true, 
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        onSubmit: () => { }, innerRef: formRef, children: ({ values }) => (_jsxs(_Fragment, { children: [_jsxs("div", { css: [
                        tablePanelStyle,
                        isFlipped &&
                            css `
                  .table-container {
                    table,
                    th {
                      position: relative !important;
                    }
                  }
                `,
                    ], children: [!isFlipped && (_jsxs(DefaultPanelHeader, { showSettingButton: true, onSettingClick: settingsPanelHandler, canDelete: false, children: [_jsx(AboutSpectrumSimulationModal, {}), _jsx(SpectrumSimulationSimpleOptions, { onSpinSystemChange: spinSystemChangeHandler, spinSystem: spinSystem })] })), isFlipped && (_jsx(PreferencesHeader, { onSave: saveSettingHandler, onClose: settingsPanelHandler })), _jsx("div", { className: "inner-container", children: !isFlipped ? (_jsxs("div", { style: {
                                    display: 'flex',
                                    flexDirection: 'column',
                                    height: '100%',
                                    overflow: 'auto',
                                }, children: [_jsx(SpinSystemTable, { spinSystem: spinSystem }), _jsx("div", { style: { padding: '5px' }, children: _jsx(Button.Done, { onClick: addSpectrumHandler, children: "Add Spectrum" }) })] })) : (_jsx(SpectrumSimulationPreferences, { ref: settingRef, options: values, onSave: saveSettingsHandler })) })] }), _jsx(FormikOnChange, { onChange: (values) => simulateHandler(values) }, Boolean(isFlipped).toString())] })) }));
}

==> nmrium-0.50.1.tgz: package/lib/component/panels/spectrumSimulation/SpectrumSimulation.js <==
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { Formik } from 'formik';
import { useCallback, useState, useRef, useMemo } from 'react';
import * as Yup from 'yup';
import { defaultSimulationOptions, } from '../../../data/data1d/spectrumSimulation';
import { useDispatch } from '../../context/DispatchContext';
import Button from '../../elements/Button';
import FormikOnChange from '../../elements/formik/FormikOnChange';
import AboutSpectrumSimulationModal from '../../modal/AboutSpectrumSimulationModal';
import { tablePanelStyle } from '../extra/BasicPanelStyle';
import DefaultPanelHeader from '../header/DefaultPanelHeader';
import PreferencesHeader from '../header/PreferencesHeader';
import SpectrumSimulationPreferences from './SpectrumSimulationPreferences';
import SpectrumSimulationSimpleOptions from './SpectrumSimulationSimpleOptions';
import { SpinSystemTable } from './SpinSystemTable';
const validationSchema = Yup.object({
    data: Yup.array().of(Yup.array().of(Yup.lazy((value) => {
        if (value === null) {
            return Yup.mixed().nullable();
        }
        return Yup.number().required();
    }))),
});
export default function SpectrumSimulation() {
    const dispatch = useDispatch();
    const [isFlipped, setFlipStatus] = useState(false);
    const [spinSystem, setSpinSystem] = useState('AB');
    const spinSystemRef = useRef('AB');
    const formRef = useRef(null);
    const settingRef = useRef(null);
    const settingsPanelHandler = useCallback(() => {
        setFlipStatus(!isFlipped);
    }, [isFlipped]);
    const saveSettingHandler = useCallback(() => {
        settingRef.current?.saveSetting();
        setFlipStatus(false);
    }, []);
    function spinSystemChangeHandler(system) {
        spinSystemRef.current = system;
        setSpinSystem(system);
    }
    const data = useMemo(() => {
        const rows = [];
        const spinLength = spinSystem.length;
        for (let i = 1; i <= spinLength; i++) {
            const columns = [];
            for (let j = 0; j < spinLength; j++) {
                if (j < i && i !== 1) {
                    columns.push(0);
                }
                else {
                    columns.push(null);
                }
            }
            columns[0] = i;
            rows.push(columns);
        }
        return rows;
    }, [spinSystem]);
    function simulateHandler(values, keepSpectrum = false) {
        if (validationSchema.isValidSync(values)) {
            dispatch({
                type: 'SIMULATE_SPECTRUM',
                payload: { ...values, spinSystem: spinSystemRef.current, keepSpectrum },
            });
        }
    }
    function addSpectrumHandler() {
        const values = formRef.current?.values;
        if (values) {
            simulateHandler(values, true);
        }
    }
    function saveSettingsHandler(values) {
        simulateHandler(values);
        void formRef.current?.setValues(values);
    }
    return (_jsx(Formik, { initialValues: { ...defaultSimulationOptions, data }, enableReinitialize: true, 
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        onSubmit: () => { }, innerRef: formRef, children: ({ values }) => (_jsxs(_Fragment, { children: [_jsxs("div", { css: [
                        tablePanelStyle,
                        isFlipped &&
                            css `
                  .table-container {
                    table,
                    th {
                      position: relative !important;
                    }
                  }
                `,
                    ], children: [!isFlipped && (_jsx(DefaultPanelHeader, { onSettingClick: settingsPanelHandler, leftButtons: [
                                {
                                    component: _jsx(AboutSpectrumSimulationModal, {}),
                                },
                            ], children: _jsx(SpectrumSimulationSimpleOptions, { onSpinSystemChange: spinSystemChangeHandler, spinSystem: spinSystem }) })), isFlipped && (_jsx(PreferencesHeader, { onSave: saveSettingHandler, onClose: settingsPanelHandler })), _jsx("div", { className: "inner-container", children: !isFlipped ? (_jsxs("div", { style: {
                                    display: 'flex',
                                    flexDirection: 'column',
                                    height: '100%',
                                    overflow: 'auto',
                                }, children: [_jsx(SpinSystemTable, { spinSystem: spinSystem }), _jsx("div", { style: { padding: '5px' }, children: _jsx(Button.Done, { onClick: addSpectrumHandler, children: "Add Spectrum" }) })] })) : (_jsx(SpectrumSimulationPreferences, { ref: settingRef, options: values, onSave: saveSettingsHandler })) })] }), _jsx(FormikOnChange, { onChange: (values) => simulateHandler(values) }, Boolean(isFlipped).toString())] })) }));
}
